Private Const MAXPINT as Integer = 32767
Private Const MAXNINT as Integer = -32768
Private Const MAXBYTE as Integer = 256

'
'' str2Val
'
' Determine the numeric value of a string.  The string may
' contain leading/trailing spaces/tabs.  The prefixes &H, &O,
' &B and &X may be used to specify the radix (case insensitive).
'
' The return value will be true if the string contained only
' valid numeric characters (including leading/trailing whitespace).
'
Private Function str2Val(	ByVal str as String, _
													ByRef okFlag as Boolean) as UnsignedLong
   Dim slen as Integer
	 Dim s as string
	 
	 
	 s = Trim(str)
   okFlag = False
   str2Val = 0
   slen = Len(s)
	 
   If (slen > 0) Then
      Dim i as Integer
      Dim isNeg as Boolean
      Dim digitCnt as Byte
      Dim c as Byte

      digitCnt = 0
      isNeg = False
			i = 1

      ' process the remaining characters, if any
      If (i <= slen) Then
         Dim pos as Byte
         Dim radix as Byte
   
         isNeg = False
         c = Asc(s, i)
         
         ' check for radix prefix
         If (c = &H26) Then
            ' determine the desired radix
            pos = StrFind("bBxXoOhH", Chr(Asc(s, i + 1)))
            If (pos = 0) Then
               radix = 0
            ElseIf (pos <= 4) Then
               radix = 2
            ElseIf (pos <=6) Then
               radix = 8
            Else
               radix = 16
            End If
            If (CBool(radix)) Then
               i = i + 2
            End If
         Else
            ' check for +/-
            pos = StrFind("+-", Chr(c))
            If (CBool(pos)) Then
               i = i + 1
               isNeg = (pos = 2)
            End If
            radix = 10
         End If
            
         If (CBool(radix)) Then
            ' convert the digits of the string to a value
            Do While (i <= slen)
               c = Asc(str, i)
               pos = StrFind("0123456789ABCDEFabcdef", Chr(c)) - 1
               If (pos > 16) Then
                  pos = pos - 6
               End If
               If (pos > radix) Then
                  Exit Do
               End If
               str2Val = (str2Val * CULng(radix)) + CULng(pos)
               i = i + 1
               digitCnt = digitCnt + 1
            Loop
         End If
      End If

      ' indicate successful scanning
      okFlag = (i > slen) And CBool(digitCnt)

      ' negate the value if necessary
      If (isNeg) Then
         str2Val = CULng(-CLng(str2Val))
      End If
   End If
	 
End Function	'Str2Val

'
'' ValueI
'
' Determine the integral value of a string of decimal digits
' optionally preceded by a minus sign.  The 'okFlag' parameter
' will be True if the string contained only valid characters
' (including leading/trailing spaces/tabs). Subroutine returns the
'	string converted to integer if successful else it sets the okFlag 
'	to FALSE. 

'	User is cautioned to check the okFlag upon return.
'

Public Sub ValueI(	ByVal str as String, _
										ByRef ival as Integer, _
										ByRef okFlag as Boolean)

	Dim val as UnsignedLong
	Dim intVal as Integer Alias val

	val = str2Val(str, okFlag)
	
	'range checks
	If (intval > MAXPINT) Then
		okFlag = FALSE
	End If
	
	If intval < MAXNINT then
		okFlag = FALSE
	End If
	
   ival = intVal
	 
End Sub	'ValueI

'
'' ValueL
'
' Determine the integral value of a string of decimal digits
' optionally preceded by a minus sign.  The 'okFlag' parameter
' will be True if the string contained only valid characters
' (including leading/trailing spaces/tabs).
'
Public Sub ValueL(	ByVal str as String, _
										ByRef lval as Long, _
										ByRef okFlag as Boolean)
						
	Dim val as UnsignedLong
   
	val = str2Val(str, okFlag)
	lval = CLng(val)
	 
End Sub	'ValueL


'
'' ValueB
'
' Determine the integral value of a string of decimal digits
' optionally preceded by a minus sign.  The 'okFlag' parameter
' will be True if the string contained only valid characters
' (including leading/trailing spaces/tabs). Subroutine returns the
'	string converted to Byte if successful else it sets the okFlag 
'	to FALSE. NOTE: byte values are only positive

'	User is cautioned to check the okFlag upon return.
'

Public Sub ValueB(ByVal str as String, _
									ByRef bval as Byte, _
									ByRef okFlag as Boolean)
									
	Dim val as UnsignedLong
	Dim ival as Integer
	
	Call ValueI(str, ival, okflag)
	If okflag Then
		okflag = (ival < MAXBYTE)
	End If
	bval = CByte(ival)
	 
End Sub	'ValueB


